@@ -13,7 +13,7 @@
 
 #include <math.h>
 
-static Eigen::MatrixXd sumKim1mat(const VectorXd &gammavec,
+inline Eigen::MatrixXd sumKim1mat(const VectorXd &gammavec,
                                   const VectorXd &xitheta,
                                   const VectorXd &kivec, const VectorXd &deltavec) {
   Eigen::MatrixXd sumterms(xitheta.size(), gammavec.size());
@@ -39,7 +39,7 @@ static Eigen::MatrixXd sumKim1mat(const VectorXd &gammavec,
 }
 
 // delta_i * fraction of exp()s
-static VectorXd deltaifrac(const VectorXd &gammavecNI, const VectorXd &xitheta,
+inline VectorXd deltaifrac(const VectorXd &gammavecNI, const VectorXd &xitheta,
                            const VectorXd &kivec, const VectorXd &deltavec) {
   // add INFINITY as the last element of gammavec
   Eigen::VectorXd gammavec(gammavecNI.size() + 1);
@@ -53,8 +53,11 @@ static VectorXd deltaifrac(const VectorXd &gammavecNI, const VectorXd &xitheta,
 
   // get the exp() terms
   Eigen::VectorXd ex(kivec.size());
+  ex.fill(0);
   Eigen::VectorXd exex(kivec.size());
+  exex.fill(0);
   Eigen::VectorXd out(kivec.size());
+  out.fill(0);
   for (int i = 0; i < kivec.size(); i++) {
 		if(deltavec(i) == 0)
 		{
@@ -77,6 +80,7 @@ static VectorXd deltaifrac(const VectorXd &gammavecNI, const VectorXd &xitheta,
 }
 
 // delta_i * fraction of exp()s for Eff score
+/*
 static VectorXd deltaifrac_EF(const VectorXd &gammavecNI, const VectorXd &gib, const VectorXd &xitheta,
                            const VectorXd &kivec, const VectorXd &deltavec) {
   // add INFINITY as the last element of gammavec
@@ -144,7 +148,7 @@ static Eigen::MatrixXd sumKim1mat_EF(const VectorXd &gammavec,const VectorXd &gi
 }
 
 
-
+*/
 
 
 #endif
